/* ========================================================================= */
/* HELPERS ================================================================= */
/* ========================================================================= */

getDevice = function() {
	return (
		window.getComputedStyle(
	    	document.querySelector('html'), ':before'
		).getPropertyValue('content')
	);
};

trimInput = function(value) {
	return value.replace(/^\s*|\s*$/g, '');
};

/* ========================================================================= */
/* FUNCTIONS =============================================================== */
/* ========================================================================= */
var siteHandler = {
	/**
	 * Carga un template con los datos que recibe como parámetro.
	 *
	 * @param  {String}   name    	- Nombre del fichero .hbs donde se encuentra el template
	 * @param  {String}   where   	- Selector CSS donde vamos a insertar el template
	 * @param  {Object}	  context	- Objeto con los datos que va a utilizar el template
	 * @param  {Boolean}  append  	- Si es true inserta el template al final de un contenedor para no borrar su contenido
	 * @param  {Function} callback  - Función de callback
	 */
	loadTemplate: function(name, where, context, append, func) {
		var location = where || '#' + name,
			data = context,
			template = JST['app/templates/' + name + '.hbs'],
			html = template(data),
			callback = func;

		if (append)
			$(location).append(html);
		else
			document.querySelector(location).innerHTML = html;
		if (func)
			callback();
	},
	/**
	 * Show/hide plants
	 *
	 * @param  {node} element - The element that fires the event
	 */
	handleClick: function(element) {
		var $this       = $(element),
			$vegWrapper = $(element).parents('.veg-wrapper'),
			$plants     = $vegWrapper.find('.plants'),
			$svgPlants  = $vegWrapper.find('.svg-plants'),
			$text 		= $vegWrapper.find('.veg-text');

		// Warning: transitionend fires for each property transitioned!
		$plants.one("webkitTransitionEnd otransitionend oTransitionEnd msTransitionEnd transitionend", function(event) {
			// Do something when the transition ends
			event.stopPropagation();
			if ($plants.hasClass('closed')) {
				$plants.hide();
			}
			else {
				var list = $plants.find('img');
				_.each(list, function(value, key, list){
					var $img  = $(value),
						$span = $(value).next();

					$img.delay(500+(100*key)).animate({ opacity: 1 }, function(){});
					$span.delay(500+(100*key)).animate({ opacity: 1 }, function(){});
					$svgPlants.fadeIn();
					$text.removeClass('fadeOut').addClass('fadeIn').show();
				});
			}

			// Enable click for current element again
			$this.one('click', function(e) {
				siteHandler.handleClick(e.currentTarget);
			});
		});

		if ($plants.hasClass('closed')){
			$plants.show(400, function() {
				// Throws transition end event
				$vegWrapper.addClass('transparency');
				$plants.removeClass('closed');
			});
		}
		else {
			$plants.find('img, span').animate({ opacity: 0 }, function(){
				// Throws transition end event
				$plants.addClass('closed');
				$vegWrapper.removeClass('transparency');
				$svgPlants.fadeOut();
				$text.hide().removeClass('fadeIn');
			});
		}
	},
	/**
	 * Scroll to bottom of previous div and show the clicked floor
	 * @param  {string} target - Element id
	 * @param  {string} previous - class of previous element
	 */
	smoothScrooll: function(target, previous){

		$plants = $(target).find('.plants');
		var before, scroll = 0;
		before = $(previous).offset().top + $(previous).outerHeight();
		scroll = $('#mainWrapper').scrollTop();
		if ($plants.hasClass('closed')){
			siteHandler.handleClick($(target+' .svg-wrapper'));
		}
		$('#mainWrapper').stop().animate({
	  		scrollTop: before - 53 +scroll
		}, 1000);
	},
	/**
	 * Establece los eventos de la app
	 */
	setEvents: {
		activeVeg: function() {
			$('.svg-wrapper').on('click', function(event) {
				// Disable click for current element (will be enabled when transition ends)
				event.preventDefault();
				$(event.currentTarget).off('click');
				// Act on the event
				siteHandler.handleClick(event.currentTarget);
			});
			// $('.plant-wrapper').on('click', function(event) {
			// 	event.preventDefault();
			// 	event.stopPropagation();
			// 	/* Act on the event */
			// });
		},
		activeFloor: function(){

			$("#legend").on('click', "polygon, path" ,function(e){
				e.preventDefault();
	            e.stopPropagation();
	            element = e.currentTarget;

	            switch(element.classList[0]){
					case 'pinar':
						siteHandler.smoothScrooll('#pinar-wrapper', '.islands-wrapper');
						break;
					case 'fayal':
						siteHandler.smoothScrooll('#fayal-brezal-wrapper', '.veg-pinar');
						break;
					case 'laurisilva':
						siteHandler.smoothScrooll('#laurisilva-wrapper', '.veg-fayal-brezal');
						break;
					case 'bosque-termofilo':
						siteHandler.smoothScrooll('#bosque-termofilo-wrapper', '.veg-laurisilva');
						break;
					case 'zona-baja':
						siteHandler.smoothScrooll('#cardonal-wrapper', '.veg-bosque-termofilo');
						break;
	            	default: break;
	            }
			});
		},
		activeLegend: function() {
			$('#curtainIcon').on('click', function(event) {
				event.preventDefault();
				$(this).find('i').toggleClass('fa-search-plus fa-search-minus');
				/* Act on the event */
				$('.legend-wrapper').toggleClass('closed');
			});
			$('#infoIcon').on('click', function(event) {
		        event.preventDefault();
		        event.stopPropagation();
		        /* Act on the event */
		        siteHandler.loadTemplate($(this).data('modal'),'#nucleusModal .modal-body');
	            $('#nucleusModal').modal();
	      	});
 		}
	},
	init: function() {
		//load template layout (header, grid, and site-canvas)
		this.loadTemplate('layout', '#mainWrapper', null, false, function(){
			siteHandler.loadTemplate('main');
			siteHandler.setEvents.activeVeg();
			siteHandler.setEvents.activeFloor();
			siteHandler.setEvents.activeLegend();
		});
	}
};

siteHandler.init();
